@@ -8,12 +8,11 @@ PIPELINE_MODULE_NAME = "alira.modules.dashboard"
 
 
 class Dashboard(module.Module):
-    def __init__(
-        self,
-        **kwargs,
-    ):
+    def __init__(self, attributes: dict() = None, **kwargs):
         super().__init__(PIPELINE_MODULE_NAME)
 
+        self.attributes = attributes
+
     def run(self, instance: Instance, **kwargs):
         result = {
             "prediction": "Positive" if instance.prediction == 1 else "Negative",
@@ -37,4 +36,21 @@ class Dashboard(module.Module):
         result["selected"] = "Yes" if selected or flagged else "No"
         result["flagged"] = "Yes" if flagged else "No"
 
+        if self.attributes:
+
+            for attribute_name, attribute_label in self.attributes.items():
+                try:
+                    attribute_value = instance.get_attribute(attribute_name)
+                    if "attributes" not in result:
+                        result["attributes"] = dict()
+
+                    result["attributes"][attribute_name] = {
+                        "label": attribute_label,
+                        "value": attribute_value,
+                    }
+                except AttributeError:
+                    # If the attribute doesn't exist, we don't want to add it
+                    # to the result.
+                    pass
+
         return result
