@@ -158,43 +158,40 @@ class EmailNotification(RedisModule):
 class SocketIO(object):
     def __init__(
         self,
-        configuration_directory: str,
-        socketio_url: str,
-        event: str = 'dispatch',
-        **kwargs
+        model_identifier: str,
+        endpoint: str,
+        event: str = "dispatch",
+        **kwargs,
     ):
-        self.configuration_directory = configuration_directory
-        self.socketio_url = socketio_url
+        self.model_identifier = model_identifier
+        self.endpoint = endpoint
         self.event = event
 
     def run(self, instance: Instance, **kwargs):
-        pipeline_id = os.path.basename(self.configuration_directory)
         payload = {
             "message": "pipeline-new-instance",
             "data": instance.__dict__,
-            "pipeline_id": pipeline_id,
+            "pipeline_id": self.model_identifier,
         }
 
-        self.emit(self.event, payload, pipeline_id)
+        self.emit(self.event, payload)
 
         return None
 
-    def emit(self, event: str, payload=None, namespace=None):
-        if not self.socketio_url:
+    def emit(self, event: str, payload=None):
+        if not self.endpoint:
             return
 
         logging.info(
-            f"Sending socket io notification to server {self.socketio_url}. Namespace {namespace}"
+            f"Sending Socket IO notification to {self.endpoint}. Namespace: {self.model_identifier}"
         )
 
         payload["event"] = event
-
-        if namespace:
-            payload["namespace"] = namespace
+        payload["namespace"] = self.model_identifier
 
         try:
             requests.post(
-                url=self.socketio_url,
+                url=self.endpoint,
                 data=json.dumps(payload),
                 headers={"Content-type": "application/json"},
             )
